"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var bt = require("@babel/types");
var path = require("path");
var parse_1 = require("../parse");
var resolvePathFrom_1 = require("../utils/resolvePathFrom");
var resolveRequired_1 = require("../utils/resolveRequired");
/**
 * Retruns documentation of the component referenced in the extends property of the component
 * @param {NodePath} astPath
 * @param {Array<NodePath>} componentDefinitions
 * @param {string} originalFilePath
 */
function extendsHandler(documentation, componentDefinition, astPath, originalFilePath) {
    var extendsVariableName = getExtendsVariableName(componentDefinition);
    // if there is no extends or extends is a direct require
    if (!extendsVariableName) {
        return;
    }
    // get all require / import statements
    var extendsFilePath = resolveRequired_1.default(astPath, [extendsVariableName]);
    var originalDirName = path.dirname(originalFilePath);
    // only look for documentation in the current project
    if (/^\./.test(extendsFilePath[extendsVariableName])) {
        var fullFilePath = resolvePathFrom_1.default(extendsFilePath[extendsVariableName], originalDirName);
        parse_1.parseFile(fullFilePath, documentation);
    }
}
exports.default = extendsHandler;
function getExtendsVariableName(compDef) {
    var extendsVariable = compDef &&
        bt.isClassDeclaration(compDef.node) &&
        compDef.node.superClass &&
        bt.isIdentifier(compDef.node.superClass)
        ? compDef.get('superClass')
        : getExtendsVariableNameFromCompDef(compDef);
    if (extendsVariable) {
        var extendsValue = bt.isProperty(extendsVariable.node)
            ? extendsVariable.node.value
            : extendsVariable.node;
        return extendsValue && bt.isIdentifier(extendsValue) ? extendsValue.name : undefined;
    }
    return undefined;
}
function getExtendsVariableNameFromCompDef(compDef) {
    if (!compDef) {
        return undefined;
    }
    var pathExtends = compDef
        .get('properties')
        .filter(function (p) { return p.node.key.name === 'extends'; });
    return pathExtends.length ? pathExtends[0] : undefined;
}
//# sourceMappingURL=extendsHandler.js.map