"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var bt = require("@babel/types");
// tslint:disable-next-line:no-var-requires
var recast = require("recast");
/**
 *
 * @param ast
 * @param varNameFilter
 */
function resolveRequired(ast, varNameFilter) {
    var varToFilePath = {};
    recast.visit(ast.program, {
        visitImportDeclaration: function (astPath) {
            var specifiers = astPath.get('specifiers');
            // if `import 'module'` without variable name cannot be a mixin
            specifiers.each(function (sp) {
                var nodeSpecifier = sp.node;
                if (bt.isImportDefaultSpecifier(nodeSpecifier) || bt.isImportSpecifier(nodeSpecifier)) {
                    var varNameDefault = nodeSpecifier.local.name;
                    if (!varNameFilter || varNameFilter.indexOf(varNameDefault) > -1) {
                        var nodeSource = astPath.get('source').node;
                        if (bt.isLiteral(nodeSource)) {
                            varToFilePath[varNameDefault] = nodeSource.value;
                        }
                    }
                }
            });
            return false;
        },
        visitVariableDeclaration: function (astPath) {
            // only look at variable declarations
            if (!bt.isVariableDeclaration(astPath.node)) {
                return false;
            }
            astPath.node.declarations.forEach(function (nodeDeclaration) {
                var sourceNode;
                var source = '';
                var init = nodeDeclaration.init && bt.isMemberExpression(nodeDeclaration.init)
                    ? nodeDeclaration.init.object
                    : nodeDeclaration.init;
                if (!init) {
                    return;
                }
                if (bt.isCallExpression(init)) {
                    if (!bt.isIdentifier(init.callee) || init.callee.name !== 'require') {
                        return;
                    }
                    sourceNode = init.arguments[0];
                    if (!bt.isLiteral(sourceNode)) {
                        return;
                    }
                    source = sourceNode.value;
                }
                else {
                    return;
                }
                if (bt.isIdentifier(nodeDeclaration.id)) {
                    var varName = nodeDeclaration.id.name;
                    varToFilePath[varName] = source;
                }
                else if (bt.isObjectPattern(nodeDeclaration.id)) {
                    nodeDeclaration.id.properties.forEach(function (p) {
                        varToFilePath[p.key.name] = source;
                    });
                }
                else {
                    return;
                }
            });
            return false;
        },
    });
    return varToFilePath;
}
exports.default = resolveRequired;
//# sourceMappingURL=resolveRequired.js.map